Module datetime

Module datetime 

Filters to format date and time strings.

Functions

add_to_environment
Add the filters to the environment
datefmt
Formats a string into a date using the jiff crate.
timefmt
Formats a string into a time using the jiff crate.